==> proc-10.1.68.tar.gz: proc/src/Plugin/Field/FieldFormatter/ProcArmouredFieldFormatter.php <==
<?php

namespace Drupal\proc\Plugin\Field\FieldFormatter;

use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceLabelFormatter;

/**
 * Plugin implementation of the 'entity reference label' formatter.
 *
 * @FieldFormatter(
 *   id = "proc_entity_reference_armoured_formatter",
 *   label = @Translation("Armoured"),
 *   description = @Translation("Display the armoured cipher text for decryption on lists."),
 *   field_types = {
 *     "proc_entity_reference_field"
 *   }
 * )
 */
class ProcArmouredFieldFormatter extends EntityReferenceLabelFormatter {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    $current_user_id = \Drupal::currentUser()->id();
    try {
      $keyring = _proc_get_keys($current_user_id, 'user_id');
    }
    catch (InvalidPluginDefinitionException | PluginNotFoundException $e) {
      return $elements;
    }
    $privkey = FALSE;
    if (!empty($keyring)) {
      $privkey = $keyring['encrypted_private_key'];
    }

    $recipient = FALSE;

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
      $recipients = $entity->get('field_recipients_set')->getValue();
      $label = $entity->label();

      $elements[$delta]['placeholder'] = [
        '#type' => 'inline_template',
        '#context' => [
          'label' => $label,
          'class' => 'proc-armoured-field-formatter',
        ],
        '#template' => '<div class="{{class}}">{{ label }}</div>',
      ];

      if (in_array($current_user_id, array_column($recipients, 'target_id'))) {
        $recipient = TRUE;
        $cipher_text = $entity->getCipherText();

        $elements[$delta]['placeholder']['#context']['value'] = $cipher_text;
        $elements[$delta]['placeholder']['#context']['pid'] = $entity->id();
        $elements[$delta]['placeholder']['#template'] = '<div id="proc-list-item-{{ pid }}" data-proc-list-item="proc-list-item-{{ pid }}" class="{{class}}" data-proc-list-item-pid="{{ pid }}" data-proc-list-item-cipher-text="{{ value|raw }}">{{ label }}</div>';
      }
    }

    if ($recipient) {
      $elements['#attached'] = [
        'library' => [
          0 => 'proc/openpgpjs',
          1 => 'proc/proc-decrypt-list',
        ],
        'drupalSettings' => [
          'proc' => [
            'proc_labels' => _proc_js_labels(),
            'proc_pass' => _proc_common_get_decryption_form_data(NULL)['proc_pass'],
            'proc_privkey' => $privkey,
            'proc_keyring_type' => $keyring['keyring_type'],
          ],
        ],
      ];
    }

    return $elements;
  }

}

==> proc-10.1.69.tar.gz: proc/src/Plugin/Field/FieldFormatter/ProcArmouredFieldFormatter.php <==
<?php

namespace Drupal\proc\Plugin\Field\FieldFormatter;

use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceLabelFormatter;

/**
 * Plugin implementation of the 'entity reference label' formatter.
 *
 * @FieldFormatter(
 *   id = "proc_entity_reference_armoured_formatter",
 *   label = @Translation("Armoured"),
 *   description = @Translation("Display the armoured cipher text for decryption on lists."),
 *   field_types = {
 *     "proc_entity_reference_field"
 *   }
 * )
 */
class ProcArmouredFieldFormatter extends EntityReferenceLabelFormatter {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    $current_user_id = \Drupal::currentUser()->id();
    try {
      $keyring = _proc_get_keys($current_user_id, 'user_id');
    }
    catch (InvalidPluginDefinitionException | PluginNotFoundException $e) {
      return $elements;
    }
    $privkey = FALSE;
    if (!empty($keyring)) {
      $privkey = $keyring['encrypted_private_key'];
    }

    $recipient = FALSE;

    $module_path = \Drupal::service('extension.list.module')->getPath('proc');
    $template_fa = $module_path . '/templates/proc.armoured_formatter.html.twig';
    $template_file_label = $module_path . '/templates/proc.label_formatter.html.twig';

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
      $recipients = $entity->get('field_recipients_set')->getValue();
      $label = $entity->label();

      $elements[$delta]['placeholder'] = [
        '#type' => 'inline_template',
        '#context' => [
          'label' => $label,
          'class' => 'proc-armoured-field-formatter',
        ],
        '#template' => file_get_contents($template_file_label),
      ];

      if (in_array($current_user_id, array_column($recipients, 'target_id'))) {
        $recipient = TRUE;

        $elements[$delta]['placeholder']['#context']['value'] = $entity->getCipherText();
        $elements[$delta]['placeholder']['#context']['pid'] = $entity->id();
        $elements[$delta]['placeholder']['#context']['type'] = $entity->getMeta()[0]['source_file_type'];
        $elements[$delta]['placeholder']['#template'] = file_get_contents($template_fa);
      }
    }

    if ($recipient) {
      $elements['#attached'] = [
        'library' => [
          0 => 'proc/openpgpjs',
          1 => 'proc/proc-decrypt-list',
        ],
        'drupalSettings' => [
          'proc' => [
            'proc_labels' => _proc_js_labels(),
            'proc_pass' => _proc_common_get_decryption_form_data(NULL)['proc_pass'],
            'proc_privkey' => $privkey,
            'proc_keyring_type' => $keyring['keyring_type'],
          ],
        ],
      ];
    }

    return $elements;
  }

}
